@@ -27,10 +27,6 @@
 #include <glib.h>
 #include <gio/gio.h>
 
-#if HAVE_WAYLAND
-#include <wayland-client.h>
-#endif
-
 #include "gnome-settings-bus.h"
 
 #define GNOME_SESSION_DBUS_NAME      "org.gnome.SessionManager"
@@ -42,6 +38,9 @@
 #define GNOME_SHELL_DBUS_NAME      "org.gnome.Shell"
 #define GNOME_SHELL_DBUS_OBJECT    "/org/gnome/Shell"
 
+#define MUTTER_DISPLAY_CONFIG_DBUS_NAME      "org.gnome.Mutter.DisplayConfig"
+#define MUTTER_DISPLAY_CONFIG_DBUS_OBJECT    "/org/gnome/Mutter/DisplayConfig"
+
 GsdSessionManager *
 gnome_settings_bus_get_session_proxy (void)
 {
@@ -121,6 +120,33 @@ gnome_settings_bus_get_shell_proxy (void)
         return shell_proxy;
 }
 
+GsdDisplayConfig *
+gnome_settings_bus_get_display_config_proxy (void)
+{
+        static GsdDisplayConfig *display_config_proxy = NULL;
+        g_autoptr(GError) error =  NULL;
+
+        if (display_config_proxy != NULL) {
+                g_object_ref (display_config_proxy);
+        } else {
+                display_config_proxy =
+                        gsd_display_config_proxy_new_for_bus_sync (G_BUS_TYPE_SESSION,
+                                                                   G_DBUS_PROXY_FLAGS_DO_NOT_AUTO_START,
+                                                                   MUTTER_DISPLAY_CONFIG_DBUS_NAME,
+                                                                   MUTTER_DISPLAY_CONFIG_DBUS_OBJECT,
+                                                                   NULL,
+                                                                   &error);
+                if (error) {
+                        g_warning ("Failed to connect to display config: %s", error->message);
+                } else {
+                        g_object_add_weak_pointer (G_OBJECT (display_config_proxy),
+                                                   (gpointer*)&display_config_proxy);
+                }
+        }
+
+        return display_config_proxy;
+}
+
 char *
 gnome_settings_get_chassis_type (void)
 {
@@ -166,29 +192,3 @@ out:
         g_clear_pointer (&variant, g_variant_unref);
         return ret;
 }
-
-static gpointer
-is_wayland_session (gpointer user_data)
-{
-#if HAVE_WAYLAND
-        struct wl_display *display;
-
-        display = wl_display_connect (NULL);
-        if (!display)
-                return GUINT_TO_POINTER(FALSE);
-        wl_display_disconnect (display);
-        return GUINT_TO_POINTER(TRUE);
-#else
-        return GUINT_TO_POINTER(FALSE);
-#endif
-}
-
-gboolean
-gnome_settings_is_wayland (void)
-{
-        static GOnce wayland_once = G_ONCE_INIT;
-
-        g_once (&wayland_once, is_wayland_session, NULL);
-
-        return GPOINTER_TO_UINT(wayland_once.retval);
-}
