@@ -49,8 +49,6 @@ typedef struct
         GClueSimple *geoclue_simple;
         GCancellable *geoclue_cancellable;
 
-        TzDB *tzdb;
-        WeatherTzDB *weather_tzdb;
         gchar *current_timezone;
 
         GSettings *location_settings;
@@ -171,23 +169,28 @@ find_by_country (GList       *locations,
         return found;
 }
 
-static const gchar *
+static gchar *
 find_timezone (GsdTimezoneMonitor *self,
                GeocodeLocation    *location,
                const gchar        *country_code)
 {
+        TzDB *tzdb;
+        gchar *res;
         GList *filtered;
+        GList *weather_locations;
         GList *locations;
-        GsdTimezoneMonitorPrivate *priv = gsd_timezone_monitor_get_instance_private (self);
         TzLocation *closest_tz_location;
 
+        tzdb = tz_load_db ();
+
         /* First load locations from Olson DB */
-        locations = ptr_array_to_list (tz_get_locations (priv->tzdb));
+        locations = ptr_array_to_list (tz_get_locations (tzdb));
         g_return_val_if_fail (locations != NULL, NULL);
 
         /* ... and then add libgweather's locations as well */
+        weather_locations = weather_tz_db_get_locations (country_code);
         locations = g_list_concat (locations,
-                                   weather_tz_db_get_locations (priv->weather_tzdb));
+                                   g_list_copy (weather_locations));
 
         /* Filter tz locations by country */
         filtered = find_by_country (locations, country_code);
@@ -202,9 +205,13 @@ find_timezone (GsdTimezoneMonitor *self,
         locations = sort_by_closest_to (locations, location);
         closest_tz_location = (TzLocation *) locations->data;
 
-        g_list_free (locations);
+        res = g_strdup (closest_tz_location->zone);
 
-        return closest_tz_location->zone;
+        g_list_free (locations);
+        g_list_free_full (weather_locations, (GDestroyNotify) tz_location_free);
+        tz_db_free (tzdb);
+
+        return res;
 }
 
 static void
@@ -214,7 +221,7 @@ process_location (GsdTimezoneMonitor *self,
         GeocodeLocation *location;
         GsdTimezoneMonitorPrivate *priv = gsd_timezone_monitor_get_instance_private (self);
         const gchar *country_code;
-        const gchar *new_timezone;
+        g_autofree gchar *new_timezone = NULL;
 
         country_code = geocode_place_get_country_code (place);
         location = geocode_place_get_location (place);
@@ -386,8 +393,6 @@ gsd_timezone_monitor_finalize (GObject *obj)
         g_clear_object (&priv->dtm);
         g_clear_object (&priv->permission);
         g_clear_pointer (&priv->current_timezone, g_free);
-        g_clear_pointer (&priv->tzdb, tz_db_free);
-        g_clear_pointer (&priv->weather_tzdb, weather_tz_db_free);
 
         g_clear_object (&priv->location_settings);
 
@@ -459,8 +464,6 @@ gsd_timezone_monitor_init (GsdTimezoneMonitor *self)
         }
 
         priv->current_timezone = timedate1_dup_timezone (priv->dtm);
-        priv->tzdb = tz_load_db ();
-        priv->weather_tzdb = weather_tz_db_new ();
 
         priv->location_settings = g_settings_new ("org.gnome.system.location");
         g_signal_connect_swapped (priv->location_settings, "changed::enabled",
