@@ -21,7 +21,6 @@
  */
 
 #include "config.h"
-#include <gtk/gtk.h>
 #include "gsd-disk-space.h"
 
 int
@@ -30,8 +29,6 @@ main (int    argc,
 {
         GMainLoop *loop;
 
-        gtk_init (&argc, &argv);
-
         loop = g_main_loop_new (NULL, FALSE);
 
         gsd_ldsm_show_empty_trash ();
