@@ -27,19 +27,12 @@
 #include <math.h>
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <gdk/gdkx.h>
-#include <X11/extensions/dpms.h>
-#include <canberra-gtk.h>
-
-#define GNOME_DESKTOP_USE_UNSTABLE_API
-#include <libgnome-desktop/gnome-rr.h>
 
 #include "gnome-settings-bus.h"
 #include "gpm-common.h"
 #include "gsd-power-constants.h"
 #include "gsd-power-manager.h"
 
-#define XSCREENSAVER_WATCHDOG_TIMEOUT           120 /* seconds */
 #define UPS_SOUND_LOOP_ID                        99
 #define GSD_POWER_MANAGER_CRITICAL_ALERT_TIMEOUT  5 /* seconds */
 
@@ -209,97 +202,6 @@ out:
         return ret;
 }
 
-/* This timer goes off every few minutes, whether the user is idle or not,
-   to try and clean up anything that has gone wrong.
-
-   It calls disable_builtin_screensaver() so that if xset has been used,
-   or some other program (like xlock) has messed with the XSetScreenSaver()
-   settings, they will be set back to sensible values (if a server extension
-   is in use, messing with xlock can cause the screensaver to never get a wakeup
-   event, and could cause monitor power-saving to occur, and all manner of
-   heinousness.)
-
-   This code was originally part of gnome-screensaver, see
-   http://git.gnome.org/browse/gnome-screensaver/tree/src/gs-watcher-x11.c?id=fec00b12ec46c86334cfd36b37771cc4632f0d4d#n530
- */
-static gboolean
-disable_builtin_screensaver (gpointer unused)
-{
-        int current_server_timeout, current_server_interval;
-        int current_prefer_blank,   current_allow_exp;
-        int desired_server_timeout, desired_server_interval;
-        int desired_prefer_blank,   desired_allow_exp;
-
-        XGetScreenSaver (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()),
-                         &current_server_timeout,
-                         &current_server_interval,
-                         &current_prefer_blank,
-                         &current_allow_exp);
-
-        desired_server_timeout  = current_server_timeout;
-        desired_server_interval = current_server_interval;
-        desired_prefer_blank    = current_prefer_blank;
-        desired_allow_exp       = current_allow_exp;
-
-        desired_server_interval = 0;
-
-        /* I suspect (but am not sure) that DontAllowExposures might have
-           something to do with powering off the monitor as well, at least
-           on some systems that don't support XDPMS?  Who know... */
-        desired_allow_exp = AllowExposures;
-
-        /* When we're not using an extension, set the server-side timeout to 0,
-           so that the server never gets involved with screen blanking, and we
-           do it all ourselves.  (However, when we *are* using an extension,
-           we tell the server when to notify us, and rather than blanking the
-           screen, the server will send us an X event telling us to blank.)
-        */
-        desired_server_timeout = 0;
-
-        if (desired_server_timeout     != current_server_timeout
-            || desired_server_interval != current_server_interval
-            || desired_prefer_blank    != current_prefer_blank
-            || desired_allow_exp       != current_allow_exp) {
-
-                g_debug ("disabling server builtin screensaver:"
-                         " (xset s %d %d; xset s %s; xset s %s)",
-                         desired_server_timeout,
-                         desired_server_interval,
-                         (desired_prefer_blank ? "blank" : "noblank"),
-                         (desired_allow_exp ? "expose" : "noexpose"));
-
-                XSetScreenSaver (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()),
-                                 desired_server_timeout,
-                                 desired_server_interval,
-                                 desired_prefer_blank,
-                                 desired_allow_exp);
-
-                XSync (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), FALSE);
-        }
-
-        return TRUE;
-}
-
-guint
-gsd_power_enable_screensaver_watchdog (void)
-{
-        int dummy;
-        guint id;
-
-        /* Make sure that Xorg's DPMS extension never gets in our
-         * way. The defaults are now applied in Fedora 20 from
-         * being "0" by default to being "600" by default */
-        gdk_x11_display_error_trap_push (gdk_display_get_default ());
-        if (DPMSQueryExtension(GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), &dummy, &dummy))
-                DPMSSetTimeouts (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), 0, 0, 0);
-        gdk_x11_display_error_trap_pop_ignored (gdk_display_get_default ());
-        id = g_timeout_add_seconds (XSCREENSAVER_WATCHDOG_TIMEOUT,
-                                    disable_builtin_screensaver,
-                                    NULL);
-        g_source_set_name_by_id (id, "[gnome-settings-daemon] disable_builtin_screensaver");
-        return id;
-}
-
 static gpointer
 parse_mock_mock_external_monitor (gpointer data)
 {
@@ -317,39 +219,21 @@ get_mock_external_monitor_file (void)
 	  return mocked_once.retval;
 }
 
-static gboolean
-randr_output_is_on (GnomeRROutput *output)
-{
-        GnomeRRCrtc *crtc;
-
-        crtc = gnome_rr_output_get_crtc (output);
-        if (!crtc)
-                return FALSE;
-        return gnome_rr_crtc_get_current_mode (crtc) != NULL;
-}
-
 static void
 mock_monitor_changed (GFileMonitor     *monitor,
 		      GFile            *file,
 		      GFile            *other_file,
-		      GFileMonitorEvent event_type,
-		      gpointer          user_data)
+		      GFileMonitorEvent event_type)
 {
-	GnomeRRScreen *screen = (GnomeRRScreen *) user_data;
+        GsdDisplayConfig *display_config =
+                gnome_settings_bus_get_display_config_proxy ();
 
-	g_debug ("Mock screen configuration changed");
-	g_signal_emit_by_name (G_OBJECT (screen), "changed");
-}
-
-static void
-screen_destroyed (gpointer  user_data,
-		  GObject  *where_the_object_was)
-{
-	g_object_unref (G_OBJECT (user_data));
+	g_debug ("Emitting mocked has-external-monitor property changed signal on %p", display_config);
+	g_object_notify (G_OBJECT (display_config), "has-external-monitor");
 }
 
 void
-watch_external_monitor (GnomeRRScreen *screen)
+watch_external_monitor (void)
 {
 	const gchar *filename;
 	GFile *file;
@@ -363,12 +247,11 @@ watch_external_monitor (GnomeRRScreen *screen)
 	monitor = g_file_monitor (file, G_FILE_MONITOR_NONE, NULL, NULL);
 	g_object_unref (file);
 	g_signal_connect (monitor, "changed",
-			  G_CALLBACK (mock_monitor_changed), screen);
-	g_object_weak_ref (G_OBJECT (screen), screen_destroyed, monitor);
+			  G_CALLBACK (mock_monitor_changed), NULL);
 }
 
 static gboolean
-mock_external_monitor_is_connected (GnomeRRScreen *screen)
+mock_external_monitor_is_connected (void)
 {
 	char *mock_external_monitor_contents;
 	const gchar *filename;
@@ -395,31 +278,48 @@ mock_external_monitor_is_connected (GnomeRRScreen *screen)
 }
 
 gboolean
-external_monitor_is_connected (GnomeRRScreen *screen)
+external_monitor_is_connected (void)
 {
-        GnomeRROutput **outputs;
-        guint i;
+        GsdDisplayConfig *display_config =
+                gnome_settings_bus_get_display_config_proxy ();
+        GDBusConnection *connection;
+        g_autoptr (GError) error = NULL;
+        g_autoptr (GVariant) variant = NULL;
+        g_autoptr (GVariant) inner = NULL;
 
         if (get_mock_external_monitor_file ())
-                return mock_external_monitor_is_connected (screen);
+                return mock_external_monitor_is_connected ();
 
-	g_assert (screen != NULL);
+        /* This needs to be a synchronous call, an up to date state is needed
+         * in response to lid changes. */
 
-        /* see if we have more than one screen plugged in */
-        outputs = gnome_rr_screen_list_outputs (screen);
-        for (i = 0; outputs[i] != NULL; i++) {
-                if (randr_output_is_on (outputs[i]) &&
-                    !gnome_rr_output_is_builtin_display (outputs[i]))
-                        return TRUE;
+        connection = g_dbus_proxy_get_connection (G_DBUS_PROXY (display_config));
+        variant = g_dbus_connection_call_sync (connection,
+                                               "org.gnome.Mutter.DisplayConfig",
+                                               "/org/gnome/Mutter/DisplayConfig",
+                                               "org.freedesktop.DBus.Properties",
+                                               "Get",
+                                               g_variant_new ("(ss)",
+                                                              "org.gnome.Mutter.DisplayConfig",
+                                                              "HasExternalMonitor"),
+                                               NULL,
+                                               G_DBUS_CALL_FLAGS_NONE,
+                                               -1,
+                                               NULL,
+                                               &error);
+        if (!variant) {
+                g_debug ("Failed to get property 'HasExternalMonitor': %s", error->message);
+                return FALSE;
         }
 
-        return FALSE;
+        g_variant_get (variant, "(v)", &inner);
+        return g_variant_get_boolean (inner);
 }
 
 static void
-play_sound (void)
+play_sound (ca_context *ca_context)
 {
-        ca_context_play (ca_gtk_context_get (), UPS_SOUND_LOOP_ID,
+        ca_context_play (ca_context, UPS_SOUND_LOOP_ID,
                          CA_PROP_EVENT_ID, "battery-caution",
                          CA_PROP_EVENT_DESCRIPTION, _("Battery is critically low"), NULL);
 }
@@ -427,30 +327,32 @@ play_sound (void)
 static gboolean
 play_loop_timeout_cb (gpointer user_data)
 {
-        play_sound ();
+        play_sound (user_data);
         return TRUE;
 }
 
 void
-play_loop_start (guint *id)
+play_loop_start (ca_context *ca_context,
+                 guint      *id)
 {
         if (*id != 0)
                 return;
 
         *id = g_timeout_add_seconds (GSD_POWER_MANAGER_CRITICAL_ALERT_TIMEOUT,
                                      (GSourceFunc) play_loop_timeout_cb,
-                                     NULL);
+                                     ca_context);
         g_source_set_name_by_id (*id, "[gnome-settings-daemon] play_loop_timeout_cb");
-        play_sound ();
+        play_sound (ca_context);
 }
 
 void
-play_loop_stop (guint *id)
+play_loop_stop (ca_context *ca_context,
+                guint      *id)
 {
         if (*id == 0)
                 return;
 
-        ca_context_cancel (ca_gtk_context_get (), UPS_SOUND_LOOP_ID);
+        ca_context_cancel (ca_context, UPS_SOUND_LOOP_ID);
         g_source_remove (*id);
         *id = 0;
 }
