@@ -21,13 +21,13 @@
 #ifndef __GSD_RFKILL_MANAGER_H
 #define __GSD_RFKILL_MANAGER_H
 
-#include <gio/gio.h>
+#include "gsd-application.h"
 
 G_BEGIN_DECLS
 
 #define GSD_TYPE_RFKILL_MANAGER         (gsd_rfkill_manager_get_type ())
 
-G_DECLARE_FINAL_TYPE (GsdRfkillManager, gsd_rfkill_manager, GSD, RFKILL_MANAGER, GApplication)
+G_DECLARE_FINAL_TYPE (GsdRfkillManager, gsd_rfkill_manager, GSD, RFKILL_MANAGER, GsdApplication)
 
 G_END_DECLS
 
