@@ -1,6 +1,3 @@
-#include <gdk/gdk.h>
-
-#define GDK_BACKEND "x11"
 #include "gsd-main-helper.h"
 #include "gsd-xsettings-manager.h"
 
@@ -11,11 +8,5 @@ main (int argc, char **argv)
         if (setup_display && *setup_display != '\0')
                 g_setenv ("DISPLAY", setup_display, TRUE);
 
-        gdk_set_allowed_backends (GDK_BACKEND);
-
-        /* GDK would fail to initialize with e.g. GDK_BACKEND=wayland */
-        g_unsetenv ("GDK_BACKEND");
-
         return gsd_main_helper (GSD_TYPE_XSETTINGS_MANAGER, argc, argv);
 }
-
